<?php
/*
 * @component QuickDownload
 * @version 2.1 "28082012"
 * @website : http://www.beesto.com
 * @copyright Copyright (C) 2011 Ionut Lupu & Popa S. Alexandru. All rights reserved.
 * @license : http://www.gnu.org/copyleft/gpl.html GNU/GPL , see license.txt
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');
jimport('joomla.utilities.date');


class QuickDownloadModelCode extends JModel
{
	protected $now;
	
	public function isAvailable ( $code ) {

		$query = ' SELECT COUNT(a.id) FROM #__quickd_codes AS a WHERE a.code = ' . $this->_db->Quote(trim($code));
		$this->_db->setQuery ( $query );
		$result = $this->_db->loadResult () ;
		
		if ( $result ) {
			
			//set the code into session so we can get the data in the next step
			JFactory::getApplication()->setUserState('com_quickdownload.code', trim($code));
			return true;
		} 
	
		return false;
	}
	
	
	public function getItems () {
	
		$code = JFactory::getApplication()->getUserState('com_quickdownload.code');
		
		// get current date
		$tz		= new DateTimeZone(JFactory::getApplication()->getCfg('offset'));
		$jdate 	= new JDate();
		$jdate->setTimezone($tz);
		$this->now = $jdate->toMySQL(true);
		
		
		if ( $code ) {
			// get details
			$query = 	' SELECT a.limit_hits_total, a.limit_hits_day, a.limit_publish_to, a.limit_publish_from, a.last_access, a.hits, a.hits_day, a.params, a.published ' .
						' FROM #__quickd_codes AS a WHERE a.code = ' . $this->_db->Quote($code) . ' LIMIT 1 ';
			$this->_db->setQuery ( $query );
			$result = $this->_db->loadObject () ;

			// check if it's published
			if ($result->published != 1) {
				$this->setError (JText::_('COM_QUICKDOWNLOAD_CODE_NOT_PUBLISHED'));
				return false;
			}
			
			//check if he started to be publish
			$publishfrom = intval($result->limit_publish_from);
			
			if ( $publishfrom > 0 ) {
				$now 			= strtotime ($this->now);				
				$publishfrom 	= strtotime ($result->limit_publish_from);
				if ($publishfrom > $now) {
					$this->setError (JText::_('COM_QUICKDOWNLOAD_CODE_NOT_AVAILABLE'));
					return false;
				}
			}
			
			
			//check if he stopped to be publish
			$publishto = intval($result->limit_publish_to);
			
			if ( $publishto > 0 ) {
				$now 		= strtotime($this->now);				
				$publishto 	= strtotime($result->limit_publish_to);
				if ($publishto < $now) {
					$this->setError (JText::_('COM_QUICKDOWNLOAD_CODE_NOT_AVAILABLE'));
					return false;
				}
			}
			
			
			// check if total number of hits is bigger than allowed
			if ( $result->limit_hits_total <= $result->hits && $result->limit_hits_total != 0 ) {
				$this->setError (JText::_('COM_QUICKDOWNLOAD_CODE_NOT_AVAILABLE'));
				return false;
			}
			
			
			// check the number of hits/day
			if ( $result->limit_hits_day != 0 ) {
				$today = date ('Y-M-d', strtotime($this->now));
				if ( intval($result->last_access) > 0 ) {
					$last = date ('Y-M-d', strtotime($result->last_access));
					if ($today == $last) {
						if ($result->hits_day >= $result->limit_hits_day) {
							$this->setError (JText::_('COM_QUICKDOWNLOAD_CODE_NOT_AVAILABLE'));
							return false;
						}
					}
				}
			}
			
			// add the last access date and increase daily hit
			$today 	= date ('Y-M-d', strtotime($this->now));
			$last 	= date ('Y-M-d', strtotime($result->last_access));
			if ( intval($result->last_access) > 0 ) {
				// if new day
				if ( $today != $last ) {
					// update last access to today date
					$query = ' UPDATE #__quickd_codes SET last_access = ' . $this->_db->quote($this->now) . ' WHERE code = ' . $this->_db->Quote($code);
					$this->_db->setQuery($query);
					$this->_db->Query();
					
					// update number of clicks with 1
					$query = ' UPDATE #__quickd_codes SET hits_day  = 1 WHERE code = ' . $this->_db->Quote($code);
					$this->_db->setQuery($query);
					$this->_db->Query();
					
				} else {
					// update number of clicks + 1
					$query = ' UPDATE #__quickd_codes SET hits_day  = (hits_day+1) WHERE code = ' . $this->_db->Quote($code);
					$this->_db->setQuery($query);
					$this->_db->Query();
				
				}
				
			} else {
				$query = ' UPDATE #__quickd_codes SET last_access = ' . $this->_db->Quote($this->now) . ' WHERE code = ' . $this->_db->Quote($code);
				$this->_db->setQuery($query);
				$this->_db->Query();
				
				// update number of clicks with 1
				$query = ' UPDATE #__quickd_codes SET hits_day  = 1 WHERE code = ' . $this->_db->Quote($code);
				$this->_db->setQuery($query);
				$this->_db->Query();
			}
				
			// add 1 hit for total
			$query = ' UPDATE #__quickd_codes SET hits  = (hits+1) WHERE code = ' . $this->_db->Quote($code);
			$this->_db->setQuery($query);
			$this->_db->Query();
				
				
			// get the file id
			$registry = new JRegistry();
			$registry->loadJSON( $result->params );
			$ids = $registry->get('files');
			
			if ($ids === 'all') {
				$query = ' SELECT a.id, a.title FROM #__quickd_files AS a WHERE a.published = 1 ';
			} else {
				$query = ' SELECT a.id, a.title FROM #__quickd_files AS a WHERE a.id IN ( ' . implode(',',$ids) . ' ) AND a.published = 1 ';
			}
			
			// get files ID and title
			$this->_db->setQuery($query);
			$files = $this->_db->loadObjectList();
			return $files;
			
		}
		
		// we make it null so he cannot access again the same page
		JFactory::getApplication()->setUserState('com_quickdownload.code', null);
	}

	



}
?>
